pyLBM.elements.Ellipsoid
========================

.. currentmodule:: pyLBM.elements

.. autoclass:: Ellipsoid

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Ellipsoid.distance
         Ellipsoid.get_bounds
         Ellipsoid.point_inside
         Ellipsoid.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Ellipsoid.number_of_bounds

